# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Labs(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    AYUMETRIX = "ayumetrix"
    SPIRIPLEX = "spiriplex"
    USSL = "ussl"
    QUEST = "quest"
    LABCORP = "labcorp"
    BIOREFERENCE = "bioreference"
    US_BIOTEK = "us_biotek"
    MANUAL = "manual"
    SANOCARDIO = "sanocardio"
    IHD = "ihd"
    NEXUS = "nexus"
    _UNKNOWN = "__LABS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Labs":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        ayumetrix: typing.Callable[[], T_Result],
        spiriplex: typing.Callable[[], T_Result],
        ussl: typing.Callable[[], T_Result],
        quest: typing.Callable[[], T_Result],
        labcorp: typing.Callable[[], T_Result],
        bioreference: typing.Callable[[], T_Result],
        us_biotek: typing.Callable[[], T_Result],
        manual: typing.Callable[[], T_Result],
        sanocardio: typing.Callable[[], T_Result],
        ihd: typing.Callable[[], T_Result],
        nexus: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Labs.AYUMETRIX:
            return ayumetrix()
        if self is Labs.SPIRIPLEX:
            return spiriplex()
        if self is Labs.USSL:
            return ussl()
        if self is Labs.QUEST:
            return quest()
        if self is Labs.LABCORP:
            return labcorp()
        if self is Labs.BIOREFERENCE:
            return bioreference()
        if self is Labs.US_BIOTEK:
            return us_biotek()
        if self is Labs.MANUAL:
            return manual()
        if self is Labs.SANOCARDIO:
            return sanocardio()
        if self is Labs.IHD:
            return ihd()
        if self is Labs.NEXUS:
            return nexus()
        return _unknown_member(self._value_)
