# This file was auto-generated by Fern from our API Definition.

import typing

from .labs import Labs
from .providers import Providers

ClientFacingSleepCycleSourceProvider = typing.Union[Providers, Labs]
