# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .source_auth_type import SourceAuthType


class SourceLink(UniversalBaseModel):
    id: int
    name: str
    slug: str
    description: str
    logo: str
    oauth_url: typing.Optional[str] = None
    auth_type: typing.Optional[SourceAuthType] = None
    form_components: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
