# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Vitamins(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    VITAMIN_A = "vitamin_a"
    VITAMIN_B_1 = "vitamin_b1"
    RIBOFLAVIN = "riboflavin"
    NIACIN = "niacin"
    PANTOTHENIC_ACID = "pantothenic_acid"
    VITAMIN_B_6 = "vitamin_b6"
    BIOTIN = "biotin"
    VITAMIN_B_12 = "vitamin_b12"
    VITAMIN_C = "vitamin_c"
    VITAMIN_D = "vitamin_d"
    VITAMIN_E = "vitamin_e"
    VITAMIN_K = "vitamin_k"
    FOLIC_ACID = "folic_acid"
    _UNKNOWN = "__VITAMINS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Vitamins":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        vitamin_a: typing.Callable[[], T_Result],
        vitamin_b_1: typing.Callable[[], T_Result],
        riboflavin: typing.Callable[[], T_Result],
        niacin: typing.Callable[[], T_Result],
        pantothenic_acid: typing.Callable[[], T_Result],
        vitamin_b_6: typing.Callable[[], T_Result],
        biotin: typing.Callable[[], T_Result],
        vitamin_b_12: typing.Callable[[], T_Result],
        vitamin_c: typing.Callable[[], T_Result],
        vitamin_d: typing.Callable[[], T_Result],
        vitamin_e: typing.Callable[[], T_Result],
        vitamin_k: typing.Callable[[], T_Result],
        folic_acid: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Vitamins.VITAMIN_A:
            return vitamin_a()
        if self is Vitamins.VITAMIN_B_1:
            return vitamin_b_1()
        if self is Vitamins.RIBOFLAVIN:
            return riboflavin()
        if self is Vitamins.NIACIN:
            return niacin()
        if self is Vitamins.PANTOTHENIC_ACID:
            return pantothenic_acid()
        if self is Vitamins.VITAMIN_B_6:
            return vitamin_b_6()
        if self is Vitamins.BIOTIN:
            return biotin()
        if self is Vitamins.VITAMIN_B_12:
            return vitamin_b_12()
        if self is Vitamins.VITAMIN_C:
            return vitamin_c()
        if self is Vitamins.VITAMIN_D:
            return vitamin_d()
        if self is Vitamins.VITAMIN_E:
            return vitamin_e()
        if self is Vitamins.VITAMIN_K:
            return vitamin_k()
        if self is Vitamins.FOLIC_ACID:
            return folic_acid()
        return _unknown_member(self._value_)
