# This file was auto-generated by Fern from our API Definition.

import typing

from .utc_timestamp_with_timezone_offset import UtcTimestampWithTimezoneOffset

SampleDataDateCollected = typing.Union[UtcTimestampWithTimezoneOffset, str]
